using System;
using System.Drawing;
using System.Net;
using System.Text;
using System.IO;

using MonoTouch.Foundation;
using MonoTouch.UIKit;

namespace UISearchBarSample
{
	public partial class SearchResults : UIViewController
	{
		StringBuilder resultText;
			
		public SearchResults () : base ("SearchResults", null)
		{
			this.Title = HomeScreen.SearchCriteria + " Results";
		}
		
		public override void DidReceiveMemoryWarning ()
		{
			// Releases the view if it doesn't have a superview.
			base.DidReceiveMemoryWarning ();
			
			// Release any cached data, images, etc that aren't in use.
		}
		
		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();
			
			// Inform user what they're searching for
			tvSearchResultsPanel.Text += "Searching for: \r\n" + HomeScreen.SearchCriteria + "\r\n";
			
			// ZIP Feeder API Call 
			var request = HttpWebRequest.Create (string.Format (@"http://www.zipfeeder.us/zip?key=x_ahVHcY&zips=" + HomeScreen.SearchCriteria));
			request.ContentType = "application/json";
			request.Method = "POST";
			
			// results text container
			resultText = new StringBuilder ();
			
			// Handle HTTP Request and HTTP Response
			using (HttpWebResponse response = request.GetResponse() as HttpWebResponse) {
				// dump any errors into the results container
				if (response.StatusCode != HttpStatusCode.OK) {
					resultText.Append ("Error fetching result. Server returned status code: " + response.StatusCode + "\r\n");
				}
				
				// catch the response and dump into the result text container
				using (StreamReader reader = new StreamReader(response.GetResponseStream())) {
					var content = reader.ReadToEnd ();
				
					if (string.IsNullOrWhiteSpace (content)) {
						resultText.Append ("Response contained an empty body.\r\n");
					} else {
						resultText.Append ("Response body: \r\n" + content);		
					}
				}
			}
			
			// populate the UITextView with the results container value
			tvSearchResultsPanel.Text += resultText.ToString();
			
		}
	
		
		public override void ViewDidUnload ()
		{
			base.ViewDidUnload ();
			
			// Clear any references to subviews of the main view in order to
			// allow the Garbage Collector to collect them sooner.
			//
			// e.g. myOutlet.Dispose (); myOutlet = null;
			
			ReleaseDesignerOutlets ();
		}
		
		public override bool ShouldAutorotateToInterfaceOrientation (UIInterfaceOrientation toInterfaceOrientation)
		{
			// Return true for supported orientations
			return (toInterfaceOrientation != UIInterfaceOrientation.PortraitUpsideDown);
		}
	}
}